@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-favicon-cache.c 7858 2008-01-13 20:42:01Z cosimoc $
+ *  $Id$
  */
 
 #include "config.h"
@@ -38,9 +38,8 @@
 #include "ephy-debug.h"
 #include "ephy-glib-compat.h"
 
-#include <glib/gstdio.h>
+#include <glib.h>
 #include <gio/gio.h>
-#include <libgnomeui/libgnomeui.h>
 
 #define EPHY_FAVICON_CACHE_XML_ROOT    (const xmlChar *)"ephy_favicons_cache"
 #define EPHY_FAVICON_CACHE_XML_VERSION (const xmlChar *)"1.1"
@@ -116,45 +115,15 @@ enum
 	NEEDS_MASK	 = 0x3f
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL];
 
-static GObjectClass *parent_class = NULL;
-
-GType
-ephy_favicon_cache_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyFaviconCacheClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) ephy_favicon_cache_class_init,
-			NULL,
-			NULL,
-			sizeof (EphyFaviconCache),
-			0,
-			(GInstanceInitFunc) ephy_favicon_cache_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "EphyFaviconCache",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (EphyFaviconCache, ephy_favicon_cache, G_TYPE_OBJECT)
 
 static void
 ephy_favicon_cache_class_init (EphyFaviconCacheClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = ephy_favicon_cache_finalize;
 
 	signals[CHANGED] =
@@ -185,7 +154,7 @@ pixbuf_cache_entry_free (PixbufCacheEntry *entry)
 		g_object_unref (entry->pixbuf);
 	}
 
-	g_free (entry);
+	g_slice_free (PixbufCacheEntry, entry);
 }
 
 static gboolean
@@ -203,7 +172,7 @@ icons_added_cb (EphyNode *node,
 		EphyNode *child,
 		EphyFaviconCache *eb)
 {
-	PixbufCacheEntry *entry = g_new0 (PixbufCacheEntry, 1);
+	PixbufCacheEntry *entry = g_slice_new0 (PixbufCacheEntry);
 
 	entry->node = child;
 
@@ -473,7 +442,7 @@ ephy_favicon_cache_finalize (GObject *object)
 	LOG ("Requests: cached %" G_GUINT64_FORMAT " / total %" G_GUINT64_FORMAT " = %.3f",
 	     priv->cached, priv->requests, ((double) priv->cached) / ((double) priv->requests));
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_favicon_cache_parent_class)->finalize (object);
 }
 
 static void
@@ -618,7 +587,7 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 	{
 		char *filename;
 
-		filename = gnome_thumbnail_md5 (url);
+		filename = g_compute_checksum_for_string (G_CHECKSUM_MD5, url, -1);
 
 		icon = ephy_node_new (cache->priv->db);
 		ephy_node_set_property_string (icon,
@@ -684,7 +653,7 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 		char *new_pix_file, *urlhash;
 		GValue value = { 0, };
 
-		urlhash = gnome_thumbnail_md5 (url);
+		urlhash = g_compute_checksum_for_string (G_CHECKSUM_MD5, url, -1);
 		new_pix_file = g_build_filename (cache->priv->directory, urlhash, NULL);
 
 		g_value_init (&value, G_TYPE_STRING);
