@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyFind.h 6707 2006-12-01 21:29:20Z chpe $
+ *  $Id$
  */
 
 #ifndef TYPEAHEADFIND_H
@@ -55,7 +55,6 @@ class EphyFind
 
     nsCOMPtr<nsITypeAheadFind> mFinder;
     PRPackedBool mAttention;
-    PRPackedBool mHasFocus;
 };
 
 #endif /* !TYPEAHEADFIND_H */
