@@ -15,13 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-search-entry.c 7358 2007-09-09 17:49:34Z cosimoc $
+ *  $Id$
  */
 
 #include "config.h"
 
-#include <gtk/gtklabel.h>
-#include <gtk/gtkentry.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
